Function

Derive Macro Function 

#[derive(Function)]
{
    // Attributes available to this derive:
    #[use_manager_ref]
    #[repr_id]
}
Derive the Function trait from oxidd_core::function

This trait can be derived for structs that wrap another Function implementation. Currently, this macro is restricted to structs with a single field.

You may specify the associated ManagerRef type using an attribute #[use_manager_ref(YourManagerRefType)].

To influence the representation identifier, use the attribute #[repr_id = "MY_BDD"].